# eric7.Plugins.VcsPlugins.vcsMercurial.HgNewProjectOptionsDialog

Module implementing the Mercurial Options Dialog for a new project from the repository.

### Global Attributes

None

### Classes

HgNewProjectOptionsDialog | Class implementing the Options Dialog for a new project from the repository.

### Functions

None

## HgNewProjectOptionsDialog

Class implementing the Options Dialog for a new project from the repository.

### Derived from

QDialog, Ui_HgNewProjectOptionsDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgNewProjectOptionsDialog | Constructor
__saveHistory | Private method to save the repository URL history.
getData | Public slot to retrieve the data entered into the dialog and to save the history of entered repository URLs.
on_vcsProjectDirPicker_textChanged | Private slot to handle a change of the project directory.
on_vcsUrlClearHistoryButton_clicked | Private slot to clear the history of entered repository URLs.
on_vcsUrlPicker_textChanged | Private slot to handle changes of the URL.

### Static Methods

None

#### HgNewProjectOptionsDialog (Constructor)

HgNewProjectOptionsDialog(vcs, parent=None)

Constructor

vcs (Hg)
  reference to the version control object
parent (QWidget)
  parent widget

#### HgNewProjectOptionsDialog.__saveHistory

__saveHistory()

Private method to save the repository URL history.

#### HgNewProjectOptionsDialog.getData

getData()

Public slot to retrieve the data entered into the dialog and to save the history of entered repository URLs.

Return:
  tuple containing the project directory and a dictionary containing the data entered

Return Type:
  tuple of (str, dict)

#### HgNewProjectOptionsDialog.on_vcsProjectDirPicker_textChanged

on_vcsProjectDirPicker_textChanged(txt)

Private slot to handle a change of the project directory.

txt (str)
  name of the project directory

#### HgNewProjectOptionsDialog.on_vcsUrlClearHistoryButton_clicked

on_vcsUrlClearHistoryButton_clicked()

Private slot to clear the history of entered repository URLs.

#### HgNewProjectOptionsDialog.on_vcsUrlPicker_textChanged

on_vcsUrlPicker_textChanged(txt)

Private slot to handle changes of the URL.

txt (str)
  current text of the line edit

Up